@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use XSLoader;
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 XSLoader::load();
 
 sub completion_helper {
@@ -81,12 +81,16 @@ includes an interface to the history library functions.
 
 If you're using a Mac, you may notice bash reads .inputrc since
 bash is statically linked with GNU readline, but this library isnt
-available for linking into other program.
+available for linking into other programs.
 
 No subroutines are exported, you must access all within the RL
 namespace. for example, instead of C<readline($prompt)>, you
 would write C<RL::readline($prompt)>.
 
+This package also comes with a script called pl, which is a repl
+for the Perl language, to quickly test commands, or do mathematical
+calculations, etc.
+
 =head1 MAIN INTERFACE
 
 =head2 readline($prompt)
@@ -209,7 +213,7 @@ thinks the screen display is correct.
 Tell the update functions that we have moved onto a new (empty)
 line, usually after outputting a newline.
 
-=head2 set_prompt(prompt)
+=head2 set_prompt($prompt)
 
 Make Readline use prompt for subsequent redisplay.
 
@@ -304,8 +308,9 @@ will start at 0 and increment until you return undef. For example:
 Calling this lets you specify a different format of completion
 function to the completion_entry_function(). This callback is
 executed when the user presses tab, and receives $text, a $start
-position, and an $end position, and you return a list of completionsas
-as an array.  The first element is the part to complete right away.
+position, and an $end position, and you return a list of completions
+as as an array.  The first element is the part to complete right
+away.
 
 So if you typed "a" and the completions were "abc1", "abc2", and
 "abc3", the list returned would be "abc", "abc1", "abc2", and "abc3".
